@@ -121,7 +121,7 @@ TQString TQtCTDEStyle::defaultStyle()
 
 void TQtCTDEStyle::polish( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
 {
-    if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+    if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget *widget = reinterpret_cast<TQWidget*>(ptr);
 
 		if ( d->useFilledFrameWorkaround )
@@ -138,7 +138,7 @@ void TQtCTDEStyle::polish( TQStyleControlElementData ceData, ControlElementFlags
 
 void TQtCTDEStyle::unPolish( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
 {
-    if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+    if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget *widget = reinterpret_cast<TQWidget*>(ptr);
 
 		if ( d->useFilledFrameWorkaround )
@@ -415,13 +415,13 @@ void TQtCTDEStyle::drawPrimitive( PrimitiveElement pe,
 
 		// Check if we are a normal toolbar or a hidden dockwidget.
 		if ( parent &&
-			(parent->inherits(TQTOOLBAR_OBJECT_NAME_STRING) ||		// Normal toolbar
-			(parent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING)) ))	// Collapsed dock
+			(parent->inherits("TQToolBar") ||		// Normal toolbar
+			(parent->inherits("TQMainWindow")) ))	// Collapsed dock
 
 			// Draw a toolbar handle
 			drawTDEStylePrimitive( KPE_ToolBarHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
 
-		else if ( widget->inherits(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING) )
+		else if ( widget->inherits("TQDockWindowHandle") )
 
 			// Draw a dock window handle
 			drawTDEStylePrimitive( KPE_DockWindowHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
@@ -779,9 +779,9 @@ int TQtCTDEStyle::pixelMetric(PixelMetric m, TQStyleControlElementData ceData, C
 			// Check that we are not a normal toolbar or a hidden dockwidget,
 			// in which case we need to adjust the height for font size
 			if (widget && (parent = widget->parentWidget() )
-				&& !parent->inherits(TQTOOLBAR_OBJECT_NAME_STRING)
-				&& !parent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING)
-				&& widget->inherits(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING) )
+				&& !parent->inherits("TQToolBar")
+				&& !parent->inherits("TQMainWindow")
+				&& widget->inherits("TQDockWindowHandle") )
 					return widget->fontMetrics().lineSpacing();
 			else
 				return TQCommonStyle::pixelMetric(m, ceData, elementFlags, widget);
@@ -1682,7 +1682,7 @@ int TQtCTDEStyle::styleHint( StyleHint sh, TQStyleControlElementData ceData, Con
 
 bool TQtCTDEStyle::objectEventHandler( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void* source, TQEvent *event )
 {
-	if (ceData.widgetObjectTypes.contains(TQOBJECT_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQObject")) {
 		TQObject* object = reinterpret_cast<TQObject*>(source);
 
 		if ( d->useFilledFrameWorkaround )
