@@ -82,7 +82,7 @@ class ShortcutHandler;
 
 class QtCurveStyle : public BASE_STYLE
 {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
 
@@ -151,7 +151,7 @@ class QtCurveStyle : public BASE_STYLE
     { drawLightBevel(cg.background(), p, r, cg, flags, round, fill, custom, doBorder, doCorners, w, widget); }
     void drawLightBevel(const TQColor &bgnd, TQPainter *p, const TQRect &r, const TQColorGroup &cg,
                         SFlags flags, int round, const TQColor &fill, const TQColor *custom=NULL,
-                        bool doBorder=true, bool doCorners=true, EWidget w=WIDGET_OTHER, const QWidget *widget=0L) const;
+                        bool doBorder=true, bool doCorners=true, EWidget w=WIDGET_OTHER, const TQWidget *widget=0L) const;
     void drawGlow(TQPainter *p, const TQRect &r, const TQColorGroup &cg, EWidget w, const TQColor *cols=0) const;
     void drawEtch(TQPainter *p, const TQRect &r, const TQColorGroup &cg, bool raised=false, bool square=false, EWidget w=WIDGET_OTHER) const;
     void drawBorder(const TQColor &bgnd, TQPainter *p, const TQRect &r, const TQColorGroup &cg,
@@ -163,8 +163,8 @@ class QtCurveStyle : public BASE_STYLE
     void drawEntryField(TQPainter *p, const TQRect &r, const TQColorGroup &cg, SFlags flags,
                         EntryColor coloration, int round, EWidget=WIDGET_ENTRY) const;
     void drawArrow(TQPainter *p, const TQRect &r, const TQColorGroup &cg, SFlags flags,
-                   TQ_PrimitiveElement pe,  bool small=false, bool checkActive=false) const;
-    void drawPrimitive(TQ_PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &,
+                   PrimitiveElement pe,  bool small=false, bool checkActive=false) const;
+    void drawPrimitive(PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &,
                        SFlags = Style_Default, const TQStyleOption & = TQStyleOption::Default) const;
     void drawTDEStylePrimitive(TDEStylePrimitive kpe, TQPainter* p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &r,
                              const TQColorGroup &cg, SFlags flags, const TQStyleOption &opt, const TQWidget* widget = 0 ) const;
